@@ -17,7 +17,7 @@ from typing import Union, Iterable, Tuple
 import numpy as np
 from bokeh.models import tools
 from chartify import Chart
-from pandas import DataFrame
+from pandas import DataFrame, concat
 
 from ..abstract_base_classes.confidence_grapher_abc import ConfidenceGrapherABC
 from ..confidence_utils import (
@@ -73,8 +73,25 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         return ch
 
     def plot_difference(
-        self, difference_df, absolute, groupby, nims: NIM_TYPE, use_adjusted_intervals: bool
+        self,
+        difference_df,
+        absolute,
+        groupby,
+        nims: NIM_TYPE,
+        use_adjusted_intervals: bool,
+        split_plot_by_groups: bool,
     ) -> ChartGrid:
+        ch = ChartGrid()
+        categorical_groups = get_remaning_groups(listify(groupby), self._ordinal_group_column)
+
+        if len(categorical_groups) == 0 or not split_plot_by_groups:
+            ch.charts += self.plot_differece_group(absolute, difference_df, groupby, use_adjusted_intervals).charts
+        else:
+            for level_name, level_df in difference_df.groupby(categorical_groups):
+                ch.charts += self.plot_differece_group(absolute, level_df, groupby, use_adjusted_intervals).charts
+        return ch
+
+    def plot_differece_group(self, absolute, difference_df, groupby, use_adjusted_intervals):
         if self._ordinal_group_column in listify(groupby):
             ch = self._ordinal_difference_plot(difference_df, absolute, groupby, use_adjusted_intervals)
             chart_grid = ChartGrid([ch])
@@ -83,12 +100,27 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         return chart_grid
 
     def plot_differences(
-        self, difference_df, absolute, groupby, nims: NIM_TYPE, use_adjusted_intervals: bool
+        self,
+        difference_df,
+        absolute,
+        groupby,
+        nims: NIM_TYPE,
+        use_adjusted_intervals: bool,
+        split_plot_by_groups: bool,
     ) -> ChartGrid:
+        ch = ChartGrid()
+        categorical_groups = get_remaning_groups(listify(groupby), self._ordinal_group_column)
 
-        remaining_groups = get_remaning_groups(groupby, self._ordinal_group_column)
-        groupby_columns = self._add_level_columns(remaining_groups)
+        if len(categorical_groups) == 0 or not split_plot_by_groups:
+            ch.charts += self.plot_differences_group(absolute, difference_df, groupby, use_adjusted_intervals).charts
+        else:
+            for level_name, level_df in difference_df.groupby(categorical_groups):
+                ch.charts += self.plot_differences_group(absolute, level_df, groupby, use_adjusted_intervals).charts
+        return ch
 
+    def plot_differences_group(self, absolute, difference_df, groupby, use_adjusted_intervals):
+        categorical_groups = get_remaning_groups(groupby, self._ordinal_group_column)
+        groupby_columns = self._add_level_columns(categorical_groups)
         if self._ordinal_group_column in listify(groupby):
             ch = self._ordinal_difference_plot(difference_df, absolute, groupby_columns, use_adjusted_intervals)
             chart_grid = ChartGrid([ch])
@@ -106,7 +138,25 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         level_as_reference,
         nims: NIM_TYPE,
         use_adjusted_intervals: bool,
+        split_plot_by_groups: bool,
     ) -> ChartGrid:
+        ch = ChartGrid()
+        categorical_groups = get_remaning_groups(listify(groupby), self._ordinal_group_column)
+
+        if len(categorical_groups) == 0 or not split_plot_by_groups:
+            ch.charts += self.plot_multiple_difference_group(
+                absolute, difference_df, groupby, level_as_reference, use_adjusted_intervals
+            ).charts
+        else:
+            for level_name, level_df in difference_df.groupby(categorical_groups):
+                ch.charts += self.plot_multiple_difference_group(
+                    absolute, level_df, groupby, level_as_reference, use_adjusted_intervals
+                ).charts
+        return ch
+
+    def plot_multiple_difference_group(
+        self, absolute, difference_df, groupby, level_as_reference, use_adjusted_intervals
+    ):
         if self._ordinal_group_column in listify(groupby):
             ch = self._ordinal_multiple_difference_plot(
                 difference_df, absolute, groupby, level_as_reference, use_adjusted_intervals
@@ -126,7 +176,9 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         if "level_1" in groupby and "level_2" in groupby:
             title = "Change from level_1 to level_2"
         else:
-            title = "Change from {} to {}".format(difference_df["level_1"].any(), difference_df["level_2"].any())
+            title = "Change from {} to {}".format(
+                difference_df["level_1"].values[0], difference_df["level_2"].values[0]
+            )
 
         y_axis_label = self._get_difference_plot_label(absolute)
         ch = self._ordinal_plot(
@@ -153,12 +205,14 @@ class ChartifyGrapher(ConfidenceGrapherABC):
     ) -> ChartGrid:
         if groupby is None:
             groupby = "dummy_groupby"
-            difference_df[groupby] = "Difference"
+            difference_df.loc[:, groupby] = "Difference"
 
         if "level_1" in groupby and "level_2" in groupby:
             title = "Change from level_1 to level_2"
         else:
-            title = "Change from {} to {}".format(difference_df["level_1"].any(), difference_df["level_2"].any())
+            title = "Change from {} to {}".format(
+                difference_df["level_1"].values[0], difference_df["level_2"].values[0]
+            )
         x_label = "" if groupby is None else "{}".format(groupby)
 
         chart_grid = self._categorical_difference_chart(
@@ -178,18 +232,20 @@ class ChartifyGrapher(ConfidenceGrapherABC):
     ) -> ChartGrid:
         LOWER, UPPER = (ADJUSTED_LOWER, ADJUSTED_UPPER) if use_adjusted_intervals else (CI_LOWER, CI_UPPER)
         axis_format, y_min, y_max = axis_format_precision(
-            numbers=(
-                difference_df[LOWER]
-                .append(difference_df[DIFFERENCE])
-                .append(difference_df[UPPER])
-                .append(difference_df[NULL_HYPOTHESIS] if NULL_HYPOTHESIS in difference_df.columns else None)
+            numbers=concat(
+                [
+                    difference_df[LOWER],
+                    difference_df[DIFFERENCE],
+                    difference_df[UPPER],
+                    difference_df[NULL_HYPOTHESIS] if NULL_HYPOTHESIS in difference_df.columns else None,
+                ],
             ),
             absolute=absolute,
         )
 
         df = (
-            difference_df.assign(**{LOWER: to_finite(difference_df[LOWER], y_min)})
-            .assign(**{UPPER: to_finite(difference_df[UPPER], y_max)})
+            difference_df.assign(**{LOWER: to_finite(difference_df[LOWER], y_min, y_max)})
+            .assign(**{UPPER: to_finite(difference_df[UPPER], y_min, y_max)})
             .assign(level_1=difference_df.level_1.map(level2str))
             .assign(level_2=difference_df.level_2.map(level2str))
             .set_index(groupby_columns)
@@ -309,11 +365,8 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         df = add_color_column(level_df, remaining_groups)
         colors = "color" if remaining_groups else None
         axis_format, y_min, y_max = axis_format_precision(
-            numbers=(
-                df[LOWER]
-                .append(df[center_name])
-                .append(df[UPPER])
-                .append(df[NULL_HYPOTHESIS] if NULL_HYPOTHESIS in df.columns else None)
+            numbers=concat(
+                [df[LOWER], df[center_name], df[UPPER], df[NULL_HYPOTHESIS] if NULL_HYPOTHESIS in df.columns else None]
             ),
             absolute=absolute,
         )
@@ -327,8 +380,8 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         ch.style.color_palette.reset_palette_order()
         ch.plot.area(
             data_frame=(
-                df.assign(**{LOWER: to_finite(df[LOWER], y_min)})
-                .assign(**{UPPER: to_finite(df[UPPER], y_max)})
+                df.assign(**{LOWER: to_finite(df[LOWER], y_min, y_max)})
+                .assign(**{UPPER: to_finite(df[UPPER], y_min, y_max)})
                 .sort_values(self._ordinal_group_column)
             ),
             x_column=self._ordinal_group_column,
@@ -372,14 +425,14 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         df = summary_df.set_index(remaining_groups).assign(categorical_x=lambda df: df.index.to_numpy()).reset_index()
 
         axis_format, y_min, y_max = axis_format_precision(
-            numbers=(df[CI_LOWER].append(df[POINT_ESTIMATE]).append(df[CI_UPPER])), absolute=True
+            numbers=concat([df[CI_LOWER], df[POINT_ESTIMATE], df[CI_UPPER]]), absolute=True
         )
 
         ch = Chart(x_axis_type="categorical")
         ch.plot.interval(
             (
-                df.assign(**{CI_LOWER: to_finite(df[CI_LOWER], y_min)}).assign(
-                    **{CI_UPPER: to_finite(df[CI_UPPER], y_max)}
+                df.assign(**{CI_LOWER: to_finite(df[CI_LOWER], y_min, y_max)}).assign(
+                    **{CI_UPPER: to_finite(df[CI_UPPER], y_min, y_max)}
                 )
             ),
             categorical_columns=remaining_groups,
@@ -458,7 +511,7 @@ class ChartifyGrapher(ConfidenceGrapherABC):
 
     def _get_multiple_difference_title(self, difference_df, level_as_reference):
         reference_level = "level_1" if level_as_reference else "level_2"
-        title = "Comparison to {}".format(difference_df[reference_level].any())
+        title = "Comparison to {}".format(difference_df[reference_level].values[0])
         return title
 
     def _add_level_column(self, groupby, level_as_reference):
@@ -517,11 +570,8 @@ class ChartifyGrapher(ConfidenceGrapherABC):
         if len(chart.figure.legend) > 0:
             chart.figure.legend.click_policy = "hide"
         axis_format, y_min, y_max = axis_format_precision(
-            numbers=(
-                df[LOWER]
-                .append(df[center_name])
-                .append(df[UPPER])
-                .append(df[NULL_HYPOTHESIS] if NULL_HYPOTHESIS in df.columns else None)
+            numbers=concat(
+                [df[LOWER], df[center_name], df[UPPER], df[NULL_HYPOTHESIS] if NULL_HYPOTHESIS in df.columns else None]
             ),
             absolute=absolute,
             extra_zeros=2,
