@@ -38,6 +38,7 @@ from spotify_confidence.analysis.constants import (
     SPOT_1_SIMES_HOCHBERG,
     NIM,
     ADJUSTED_ALPHA,
+    ORIGINAL_POINT_ESTIMATE,
 )
 from spotify_confidence.analysis.frequentist.sequential_bound_solver import bounds
 
@@ -62,7 +63,7 @@ def variance(df: DataFrame, arg_dict: Dict[str, str]) -> float:
     if binary.all():
         # This equals row[POINT_ESTIMATE]*(1-row[POINT_ESTIMATE]) when the data is binary,
         # and also gives a robust fallback in case it's not
-        variance = df[numerator_sumsq] / df[denominator] - df[POINT_ESTIMATE] ** 2
+        variance = df[numerator_sumsq] / df[denominator] - df[ORIGINAL_POINT_ESTIMATE] ** 2
     else:
         variance = (df[numerator_sumsq] - np.power(df[numerator], 2) / df[denominator]) / (df[denominator] - 1)
     if (variance < 0).any():
@@ -120,6 +121,9 @@ def compute_sequential_adjusted_alpha(df: DataFrame, arg_dict: Dict[str, str]):
     ordinal_group_column = arg_dict[ORDINAL_GROUP_COLUMN]
     n_comparisons = arg_dict[NUMBER_OF_COMPARISONS]
 
+    if not df.reset_index()[ordinal_group_column].is_unique:
+        raise ValueError("Ordinal values cannot be duplicated")
+
     def adjusted_alphas_for_group(grp: DataFrame) -> Series:
         return (
             sequential_bounds(
@@ -140,31 +144,16 @@ def compute_sequential_adjusted_alpha(df: DataFrame, arg_dict: Dict[str, str]):
             )
         )[["zb", ADJUSTED_ALPHA]]
 
-    groups_except_ordinal = [column for column in df.index.names if column != ordinal_group_column]
-    max_sample_size_by_group = (
-        (
-            df[["current_total_" + denominator, final_expected_sample_size_column]]
-            .groupby(groups_except_ordinal, sort=False)
-            .max()
-            .max(axis=1)
-        )
-        if len(groups_except_ordinal) > 0
-        else (df[["current_total_" + denominator, final_expected_sample_size_column]].max().max())
-    )
-    sample_size_proportions = Series(
-        data=df.groupby(df.index.names, sort=False)["current_total_" + denominator].first() / max_sample_size_by_group,
-        name="sample_size_proportions",
-    )
-
+    comparison_total_column = "comparison_total_" + denominator
     return Series(
-        data=df.groupby(df.index.names, sort=False)[[ALPHA, PREFERENCE_TEST]]
-        .first()
-        .merge(sample_size_proportions, left_index=True, right_index=True)
-        .assign(_sequential_dummy_index_=1)
-        .groupby(groups_except_ordinal + ["_sequential_dummy_index_"], sort=False)[
-            ["sample_size_proportions", PREFERENCE_TEST, ALPHA]
-        ]
-        .apply(adjusted_alphas_for_group)[ADJUSTED_ALPHA],
+        data=(
+            df.assign(**{comparison_total_column: df[denominator + SFX1] + df[denominator + SFX2]})
+            .assign(
+                max_sample_size=lambda df: df[[comparison_total_column, final_expected_sample_size_column]].max(axis=1)
+            )
+            .assign(sample_size_proportions=lambda df: df[comparison_total_column] / df["max_sample_size"])
+            .pipe(adjusted_alphas_for_group)[ADJUSTED_ALPHA]
+        ),
         name=ADJUSTED_ALPHA,
     )
 
